"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const color_1 = require("../util/color");
const createPaletteItem = (paletteItem, theme) => {
    var _a;
    let result = {};
    if (typeof paletteItem === 'string') {
        result.main = paletteItem;
    }
    else {
        result = Object.assign({}, paletteItem);
        if (!result.main) {
            console.error('Palette main color is missing...');
        }
    }
    const mainColor = (0, color_1.getColor)(result.main);
    result.background || (result.background = result.main);
    result.font || (result.font = (0, color_1.getFontColor)(result.main, theme));
    result.shadow || (result.shadow = mainColor.alpha(.5).rgb().toString());
    result.dark || (result.dark = mainColor.darken(.10).hex().toString());
    result.darker || (result.darker = (0, color_1.getColor)(result.dark).darken(.05).hex().toString());
    result.darkest || (result.darkest = (0, color_1.getColor)(result.darker).darken(.05).hex().toString());
    result.light || (result.light = mainColor.lighten(.10).hex().toString());
    result.lighter || (result.lighter = (0, color_1.getColor)(result.light).lighten(.05).hex().toString());
    result.lightest || (result.lightest = (0, color_1.getColor)(result.lighter).lighten(.05).hex().toString());
    result.dynamic = theme.$.vars.isDarkMode ? result.light : result.dark;
    result.dynamicer = theme.$.vars.isDarkMode ? result.lighter : result.darker;
    result.dynamicest = theme.$.vars.isDarkMode ? result.lightest : result.darkest;
    if (theme.$.vars.isDarkMode) {
        result.soft || (result.soft = (0, color_1.getColor)((0, color_1.mix)(result.main, .8)).lighten(.6).hex().toString());
        result.softFont || (result.softFont = result.main);
        result.softDynamic || (result.softDynamic = (0, color_1.getColor)(result.soft).lighten(.25).hex().toString());
        result.softDynamicer || (result.softDynamicer = (0, color_1.getColor)(result.soft).lighten(.4).hex().toString());
        result.softDynamicest || (result.softDynamicest = (0, color_1.getColor)(result.soft).lighten(.5).hex().toString());
    }
    else {
        result.soft || (result.soft = (0, color_1.mix)(result.main, -.8));
        result.softFont || (result.softFont = (0, color_1.mix)(result.main, .4));
        result.softDynamic || (result.softDynamic = (0, color_1.mix)(result.main, -.72));
        result.softDynamicer || (result.softDynamicer = (0, color_1.mix)(result.main, -.65));
        result.softDynamicest || (result.softDynamicest = (0, color_1.mix)(result.main, -.55));
    }
    const waveEffect = (0, color_1.getColor)((_a = result.waveEffect) !== null && _a !== void 0 ? _a : result.main);
    result.waveEffect = `radial-gradient(${waveEffect.alpha(.2).toString()} 0, ${waveEffect.alpha(.3).toString()} 40%, ${waveEffect.alpha(.4).toString()} 50%, ${waveEffect.alpha(.5).toString()} 60%, ${waveEffect.alpha(0).toString()} 70%)`;
    return result;
};
exports.default = createPaletteItem;
